# encoding: utf-8
#
# Copyright (C) 2016-2023 Alois Schlögl <alois.schloegl@gmail.com>
#
#    This file is part of the BioSig repository
#    at https://biosig.sourceforge.io/
#
#    BioSig is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 3
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

#----> DO NOT EDIT  setup.py <-----#
#   setup.py is autogenerated from setup.py.in

# TODO:
#   windows, how to add libbiosig.dll.a and alike
#   https://docs.python.org/3/install/index.html#gnu-c-cygwin-mingw
#   check impact of https://peps.python.org/pep-0632/
#	https://numpy.org/devdocs/reference/distutils_status_migration.html
#       https://numpy.org/doc/stable/reference/distutils_status_migration.html#numpy-setuptools-interaction
#       https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration

try:
    from setuptools import setup, Extension
except ImportError:
    from distutils.core import setup
    from distutils.extension import Extension

import os
import numpy

module_biosig = Extension('biosig',
        define_macros = [('MAJOR_VERSION', '2.6.0'[:1] ), ('MINOR_VERSION', '2.6.0'[2:3])],
        include_dirs = ['./..', numpy.get_include()],
        libraries    = ['biosig'],
        library_dirs = ['./..','../lib'],
        sources      = ['biosigmodule.c'])

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup (name = 'Biosig',
        version = '2.6.0',
        description = 'BioSig - tools for biomedical signal processing',
        author = 'Alois Schlögl',
        author_email = 'alois.schloegl@gmail.com',
        license = 'GPLv3+',
        url = 'https://biosig.sourceforge.io',
        #long_description='Import filters of biomedical signal formats',
        long_description=read('README.md'),
        long_description_content_type="text/markdown",
        include_package_data = True,
        keywords = 'EEG ECG EKG EMG EOG Polysomnography ECoG biomedical signals SCP EDF GDF HEKA CFS ABF',
        setup_requires=['setuptools >=6.0'],
        install_requires=['numpy'],
        classifiers=[
          'Programming Language :: Python',
          'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
          'Operating System :: OS Independent'
        ],
        ext_modules = [module_biosig])
